@@ -58,8 +58,9 @@ public class JDBCSecurityImpl {
             UserGroupInformation.loginUserFromKeytab(principal, keytab);
             LOGGER.info("Login successfully via keytab: {} and principal: {}", keytab, principal);
           } else {
+            UserGroupInformation.getCurrentUser().checkTGTAndReloginFromKeytab();
             LOGGER.info("The user has already logged in using Keytab and principal, " +
-                "no action required");
+                "will check tgt and whether to re-login");
           }
         } catch (IOException e) {
           LOGGER.error("Failed to get either keytab location or principal name in the " +
