@@ -16,6 +16,7 @@
  */
 package org.apache.zeppelin.graph.neo4j;
 
+import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.gson.Gson;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.zeppelin.graph.neo4j.Neo4jConnectionManager.Neo4jAuthType;
@@ -25,37 +26,38 @@ import org.apache.zeppelin.interpreter.InterpreterResult;
 import org.apache.zeppelin.interpreter.InterpreterResult.Code;
 import org.apache.zeppelin.interpreter.graph.GraphResult;
 import org.apache.zeppelin.tabledata.Node;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.ClassRule;
-import org.junit.FixMethodOrder;
-import org.junit.Test;
-import org.junit.runners.MethodSorters;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestMethodOrder;
+import org.junit.jupiter.api.MethodOrderer;
 import org.neo4j.driver.Driver;
 import org.neo4j.driver.GraphDatabase;
 import org.neo4j.driver.Session;
 import org.testcontainers.containers.Neo4jContainer;
-import org.testcontainers.shaded.com.fasterxml.jackson.core.JsonProcessingException;
-import org.testcontainers.shaded.com.fasterxml.jackson.databind.ObjectMapper;
+import org.testcontainers.junit.jupiter.Container;
+import org.testcontainers.junit.jupiter.Testcontainers;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
+import java.io.IOException;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-
-@FixMethodOrder(MethodSorters.NAME_ASCENDING)
+@Testcontainers
+@TestMethodOrder(MethodOrderer.MethodName.class)
 public class Neo4jCypherInterpreterTest {
 
   private Neo4jCypherInterpreter interpreter;
 
   private InterpreterContext context;
 
-  @ClassRule
+  @Container
   public static Neo4jContainer<?> neo4jContainer = new Neo4jContainer<>("neo4j:4.1.1")
           .withoutAuthentication();
 
@@ -75,7 +77,7 @@ public class Neo4jCypherInterpreterTest {
   private static final String TABLE_RESULT_PREFIX = "%table ";
   private static final String NETWORK_RESULT_PREFIX = "%network ";
 
-  @BeforeClass
+  @BeforeAll
   public static void setUpNeo4jServer() {
     try (Driver driver = GraphDatabase.driver(neo4jContainer.getBoltUrl());
          Session session = driver.session()) {
@@ -84,7 +86,7 @@ public class Neo4jCypherInterpreterTest {
     }
   }
 
-  @Before
+  @BeforeEach
   public void setUpZeppelin() {
     Properties p = new Properties();
     p.setProperty(Neo4jConnectionManager.NEO4J_SERVER_URL, neo4jContainer.getBoltUrl());
@@ -97,13 +99,13 @@ public class Neo4jCypherInterpreterTest {
         .build();
   }
 
-  @After
+  @AfterEach
   public void tearDownZeppelin() throws Exception {
     interpreter.close();
   }
 
   @Test
-  public void testTableWithArray() {
+  void testTableWithArray() {
     interpreter.open();
     InterpreterResult result = interpreter.interpret(
             "return 'a' as colA, 'b' as colB, [1, 2, 3] as colC", context);
@@ -121,7 +123,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testCreateIndex() {
+  void testCreateIndex() {
     interpreter.open();
     InterpreterResult result = interpreter.interpret("CREATE INDEX ON :Person(name)", context);
     assertEquals(Code.SUCCESS, result.code());
@@ -129,7 +131,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testRenderTable() {
+  void testRenderTable() {
     interpreter.open();
     InterpreterResult result = interpreter.interpret("MATCH (n:Person) "
             + "WHERE n.name IN ['name1', 'name2', 'name3'] "
@@ -144,7 +146,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testRenderMap() {
+  void testRenderMap() {
     interpreter.open();
     final String jsonQuery =
             "RETURN {key: \"value\", listKey: [{inner: \"Map1\"}, {inner: \"Map2\"}]} as object";
@@ -231,7 +233,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testRenderNetwork() {
+  void testRenderNetwork() {
     interpreter.open();
     InterpreterResult result = interpreter.interpret(
             "MATCH (n)-[r:KNOWS]-(m) RETURN n, r, m LIMIT 1", context);
@@ -249,7 +251,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testFallingQuery() {
+  void testFallingQuery() {
     interpreter.open();
     final String errorMsgEmpty = "";
     InterpreterResult result = interpreter.interpret(StringUtils.EMPTY, context);
@@ -266,7 +268,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testDates() {
+  void testDates() {
     InterpreterResult result = interpreter.interpret(
             "RETURN datetime('2015-06-24T12:50:35.556+0100') AS theDateTime", context);
     assertEquals(Code.SUCCESS, result.code());
@@ -296,7 +298,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testDuration() {
+  void testDuration() {
     InterpreterResult result = interpreter.interpret(
             "RETURN duration('P14DT16H12M') AS theDuration", context);
     assertEquals(Code.SUCCESS, result.code());
@@ -305,7 +307,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testPoint() {
+  void testPoint() {
     InterpreterResult result = interpreter.interpret("RETURN point({ x:3, y:0 }) AS cartesian_2d,"
             + "point({ x:0, y:4, z:1 }) AS cartesian_3d,"
             + "point({ latitude: 12, longitude: 56 }) AS geo_2d,"
@@ -327,7 +329,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testMultiLineInterpreter() {
+  void testMultiLineInterpreter() {
     Properties p = new Properties();
     p.setProperty(Neo4jConnectionManager.NEO4J_SERVER_URL, neo4jContainer.getBoltUrl());
     p.setProperty(Neo4jConnectionManager.NEO4J_AUTH_TYPE, Neo4jAuthType.NONE.toString());
@@ -358,7 +360,7 @@ public class Neo4jCypherInterpreterTest {
   }
 
   @Test
-  public void testNodeDataTypes() throws JsonProcessingException {
+  void testNodeDataTypes() throws IOException {
     InterpreterResult result = interpreter.interpret(
             "CREATE (n:NodeTypes{" +
                     "dateTime: datetime('2015-06-24T12:50:35.556+0100')," +
