@@ -17,8 +17,6 @@
 
 package org.apache.zeppelin.spark;
 
-
-import junit.framework.TestCase;
 import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.zeppelin.interpreter.Interpreter;
 import org.apache.zeppelin.interpreter.InterpreterContext;
@@ -31,7 +29,8 @@ import org.apache.zeppelin.interpreter.LazyOpenInterpreter;
 import org.apache.zeppelin.interpreter.remote.RemoteInterpreterEventClient;
 import org.apache.zeppelin.interpreter.thrift.InterpreterCompletion;
 import org.apache.zeppelin.python.IPythonInterpreterTest;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 import java.nio.file.Files;
@@ -40,9 +39,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.reset;
@@ -101,6 +100,7 @@ public class IPySparkInterpreterTest extends IPythonInterpreterTest {
 
 
   @Override
+  @AfterEach
   public void tearDown() throws InterpreterException {
     intpGroup.close();
     interpreter = null;
@@ -133,51 +133,30 @@ public class IPySparkInterpreterTest extends IPythonInterpreterTest {
 
     // spark sql
     context = createInterpreterContext(mockIntpEventClient);
-    if (isSpark1(sparkVersion)) {
-      result = interpreter.interpret("df = sqlContext.createDataFrame([(1,'a'),(2,'b')])\ndf.show()", context);
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-      interpreterResultMessages = context.out.toInterpreterResultMessage();
-      assertEquals(
-          "+---+---+\n" +
-              "| _1| _2|\n" +
-              "+---+---+\n" +
-              "|  1|  a|\n" +
-              "|  2|  b|\n" +
-              "+---+---+", interpreterResultMessages.get(0).getData().trim());
+    result = interpreter.interpret("df = spark.createDataFrame([(1,'a'),(2,'b')])\ndf.show()", context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    interpreterResultMessages = context.out.toInterpreterResultMessage();
+    assertEquals(
+        "+---+---+\n" +
+            "| _1| _2|\n" +
+            "+---+---+\n" +
+            "|  1|  a|\n" +
+            "|  2|  b|\n" +
+            "+---+---+", interpreterResultMessages.get(0).getData().trim());
 
-      context = createInterpreterContext(mockIntpEventClient);
-      result = interpreter.interpret("z.show(df)", context);
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-      interpreterResultMessages = context.out.toInterpreterResultMessage();
-      assertEquals(
-          "_1	_2\n" +
-              "1	a\n" +
-              "2	b", interpreterResultMessages.get(0).getData().trim());
-    } else {
-      result = interpreter.interpret("df = spark.createDataFrame([(1,'a'),(2,'b')])\ndf.show()", context);
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-      interpreterResultMessages = context.out.toInterpreterResultMessage();
-      assertEquals(
-          "+---+---+\n" +
-              "| _1| _2|\n" +
-              "+---+---+\n" +
-              "|  1|  a|\n" +
-              "|  2|  b|\n" +
-              "+---+---+", interpreterResultMessages.get(0).getData().trim());
+    context = createInterpreterContext(mockIntpEventClient);
+    result = interpreter.interpret("z.show(df)", context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
+    interpreterResultMessages = context.out.toInterpreterResultMessage();
+    assertEquals(
+        "_1	_2\n" +
+            "1	a\n" +
+            "2	b", interpreterResultMessages.get(0).getData().trim());
 
-      context = createInterpreterContext(mockIntpEventClient);
-      result = interpreter.interpret("z.show(df)", context);
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-      interpreterResultMessages = context.out.toInterpreterResultMessage();
-      assertEquals(
-          "_1	_2\n" +
-              "1	a\n" +
-              "2	b", interpreterResultMessages.get(0).getData().trim());
+    // spark sql python API bindings
+    result = interpreter.interpret("df.explain()", context);
+    assertEquals(InterpreterResult.Code.SUCCESS, result.code());
 
-      // spark sql python API bindings
-      result = interpreter.interpret("df.explain()", context);
-      assertEquals(InterpreterResult.Code.SUCCESS, result.code());
-    }
     // cancel
     if (interpreter instanceof IPySparkInterpreter) {
       final InterpreterContext context2 = createInterpreterContext(mockIntpEventClient);
@@ -269,14 +248,10 @@ public class IPySparkInterpreterTest extends IPythonInterpreterTest {
       fail("Should not be able to start IPythonInterpreter");
     } catch (InterpreterException e) {
       String exceptionMsg = ExceptionUtils.getStackTrace(e);
-      TestCase.assertTrue(exceptionMsg, exceptionMsg.contains("No such file or directory"));
+      assertTrue(exceptionMsg.contains("No such file or directory"), exceptionMsg);
     }
   }
 
-  private static boolean isSpark1(String sparkVersion) {
-    return sparkVersion.startsWith("'1.") || sparkVersion.startsWith("u'1.");
-  }
-
   private static InterpreterContext createInterpreterContext(RemoteInterpreterEventClient mockRemoteEventClient) {
     return InterpreterContext.builder()
         .setNoteId("noteId")
