@@ -67,13 +67,17 @@ import java.util.regex.Pattern;
  * The Shiro configuration section should be configured as:
  * [main]
  * krbRealm = org.apache.zeppelin.realm.kerberos.KerberosRealm
- * krbRealm.principal=HTTP/zeppelin.fqdn.domain.com@EXAMPLE.COM
- * krbRealm.keytab=/etc/security/keytabs/spnego.service.keytab
- * krbRealm.nameRules=DEFAULT
- * krbRealm.signatureSecretFile=/etc/security/http_secret
- * krbRealm.tokenValidity=36000
- * krbRealm.cookieDomain=domain.com
- * krbRealm.cookiePath=/
+ * krbRealm.principal = HTTP/zeppelin.fqdn.domain.com@EXAMPLE.COM
+ * krbRealm.keytab = /etc/security/keytabs/spnego.service.keytab
+ * krbRealm.nameRules = DEFAULT
+ * krbRealm.signatureSecretFile = /etc/security/http_secret
+ * krbRealm.tokenValidity = 36000
+ * krbRealm.cookieDomain = domain.com
+ * krbRealm.cookiePath = /
+ * krbRealm.logout = logout
+ * krbRealm.logoutAPI = true
+ * krbRealm.providerUrl = https://domain.example.com/
+ * krbRealm.redirectParam = originalUrl
  * authc = org.apache.zeppelin.realm.kerberos.KerberosAuthenticationFilter
  *
  */
@@ -91,6 +95,10 @@ public class KerberosRealm extends AuthorizingRealm {
   private boolean isCookiePersistent = false;
   private String signatureSecretFile = null;
   private String signatureSecretProvider = "file";
+  private String logout = "logout";
+  private Boolean logoutAPI = true;
+  private String providerUrl = "https://domain.example.com/";
+  private String redirectParam = "originalUrl";
 
   /**
    * Constant for the property that specifies the authentication handler to use.
@@ -167,6 +175,11 @@ public class KerberosRealm extends AuthorizingRealm {
    * implementation will be used.
    */
   private static final String SIGNER_SECRET_PROVIDER = "signer.secret.provider";
+  /**
+   * Constant for the configuration property that indicates the path to use to logout
+   */
+  private static final String LOGOUT = "logout";
+
 
   private static Signer signer = null;
   private SignerSecretProvider secretProvider = null;
@@ -247,12 +260,7 @@ public class KerberosRealm extends AuthorizingRealm {
       if (null == gssManager) {
         try {
           gssManager = Subject.doAs(serverSubject,
-              new PrivilegedExceptionAction<GSSManager>() {
-                @Override
-                public GSSManager run() {
-                  return GSSManager.getInstance();
-                }
-              });
+                  (PrivilegedExceptionAction<GSSManager>) GSSManager::getInstance);
           LOG.trace("SPNEGO gssManager initialized.");
         } catch (PrivilegedActionException ex) {
           throw ex.getException();
@@ -273,7 +281,7 @@ public class KerberosRealm extends AuthorizingRealm {
 
   private void initializeSecretProvider() throws ServletException {
     try {
-      secretProvider = constructSecretProvider(true);
+      secretProvider = constructSecretProvider();
       destroySecretProvider = true;
       signer = new Signer(secretProvider);
     } catch (Exception ex) {
@@ -281,13 +289,11 @@ public class KerberosRealm extends AuthorizingRealm {
     }
   }
 
-  private SignerSecretProvider constructSecretProvider(
-      boolean fallbackToRandomSecretProvider) throws Exception {
+  private SignerSecretProvider constructSecretProvider() throws Exception {
     SignerSecretProvider provider;
     String secretProvider = config.getProperty(SIGNER_SECRET_PROVIDER);
 
-    if (fallbackToRandomSecretProvider
-        && config.getProperty(SIGNATURE_SECRET_FILE) == null) {
+    if (config.getProperty(SIGNATURE_SECRET_FILE) == null) {
       secretProvider = "random";
     }
 
@@ -297,16 +303,11 @@ public class KerberosRealm extends AuthorizingRealm {
         provider.init(config, null, tokenValidity);
         LOG.info("File based secret signer initialized.");
       } catch (Exception e) {
-        if (fallbackToRandomSecretProvider) {
-          LOG.info("Unable to initialize FileSignerSecretProvider, " +
-              "falling back to use random secrets.");
-          provider = new RandomSignerSecretProvider();
-          provider.init(config, null, tokenValidity);
-          LOG.info("Random secret signer initialized.");
-        } else {
-          throw new RuntimeException("Can't initialize File based secret signer. Reason: "
-          + e);
-        }
+        LOG.info("Unable to initialize FileSignerSecretProvider, " +
+            "falling back to use random secrets.");
+        provider = new RandomSignerSecretProvider();
+        provider.init(config, null, tokenValidity);
+        LOG.info("Random secret signer initialized.");
       }
     } else if ("random".equals(secretProvider)) {
       provider = new RandomSignerSecretProvider();
@@ -327,8 +328,6 @@ public class KerberosRealm extends AuthorizingRealm {
    * @param response the HTTP client response.
    *
    * @return <code>TRUE</code>
-   * @throws IOException it is never thrown.
-   * @throws AuthenticationException it is never thrown.
    */
   public boolean managementOperation(AuthenticationToken token,
                                      HttpServletRequest request,
@@ -356,7 +355,7 @@ public class KerberosRealm extends AuthorizingRealm {
   public Set<String> mapGroupPrincipals(final String mappedPrincipalName)
       throws AuthorizationException {
     /* return the groups as seen by Hadoop */
-    Set<String> groups = null;
+    Set<String> groups;
     try {
       hadoopGroups.refresh();
       final List<String> groupList = hadoopGroups.getGroups(mappedPrincipalName);
@@ -375,7 +374,7 @@ public class KerberosRealm extends AuthorizingRealm {
         LOG.info(String.format("errorGettingUserGroups for %s", mappedPrincipalName));
         throw new AuthorizationException(e);
       }
-      groups = new HashSet();
+      groups = new HashSet<>();
     }
     return groups;
   }
@@ -590,13 +589,8 @@ public class KerberosRealm extends AuthorizingRealm {
                   "decoded from client request");
         }
         token = Subject.doAs(serverSubject,
-            new PrivilegedExceptionAction<AuthenticationToken>() {
-              @Override
-              public AuthenticationToken run() throws Exception {
-                return runWithPrincipal(serverPrincipal, clientToken,
-                    base64, response);
-              }
-            });
+                (PrivilegedExceptionAction<AuthenticationToken>) () -> runWithPrincipal(serverPrincipal, clientToken,
+                    base64, response));
       } catch (PrivilegedActionException ex) {
         if (ex.getException() instanceof IOException) {
           throw (IOException) ex.getException();
@@ -688,7 +682,6 @@ public class KerberosRealm extends AuthorizingRealm {
    *
    * @param request request object.
    * @return the Authentication token if the request is authenticated, <code>null</code> otherwise.
-   * @throws IOException             thrown if an IO error occurred.
    * @throws AuthenticationException thrown if the token is invalid or if it has expired.
    */
   private AuthenticationToken getToken(HttpServletRequest request)
@@ -878,6 +871,7 @@ public class KerberosRealm extends AuthorizingRealm {
     props.put(PRINCIPAL, principal);
     props.put(KEYTAB, keytab);
     props.put(NAME_RULES, nameRules);
+    props.put(LOGOUT, logout);
     return props;
   }
 
@@ -982,6 +976,38 @@ public class KerberosRealm extends AuthorizingRealm {
     this.signatureSecretProvider = signatureSecretProvider;
   }
 
+  public String getLogout() {
+    return logout;
+  }
+
+  public void setLogout(String logout) {
+    this.logout = logout;
+  }
+
+  public Boolean getLogoutAPI() {
+    return logoutAPI;
+  }
+
+  public void setLogoutAPI(Boolean logoutAPI) {
+    this.logoutAPI = logoutAPI;
+  }
+
+  public String getProviderUrl() {
+    return providerUrl;
+  }
+
+  public void setProviderUrl(String providerUrl) {
+    this.providerUrl = providerUrl;
+  }
+
+  public String getRedirectParam() {
+    return redirectParam;
+  }
+
+  public void setRedirectParam(String redirectParam) {
+    this.redirectParam = redirectParam;
+  }
+
   /**
    * Releases any resources initialized by the authentication handler.
    * <p>
