@@ -27,16 +27,21 @@ import org.apache.zeppelin.service.ServiceContext;
 import org.apache.zeppelin.service.SimpleServiceCallback;
 import org.apache.zeppelin.user.AuthenticationInfo;
 
+import com.google.gson.Gson;
+
 public class AbstractRestApi {
 
   protected AuthenticationService authenticationService;
 
+  protected static final Gson GSON = new Gson();
+
   protected AbstractRestApi(AuthenticationService authenticationService) {
     this.authenticationService = authenticationService;
   }
 
   protected ServiceContext getServiceContext() {
     AuthenticationInfo authInfo = new AuthenticationInfo(authenticationService.getPrincipal());
+    authInfo.setRoles(authenticationService.getAssociatedRoles());
     Set<String> userAndRoles = new HashSet<>();
     userAndRoles.add(authenticationService.getPrincipal());
     userAndRoles.addAll(authenticationService.getAssociatedRoles());
