@@ -16,12 +16,9 @@
  */
 package org.apache.zeppelin.rest.message;
 
-import com.google.gson.Gson;
-
 import java.util.List;
 import java.util.Map;
 
-import org.apache.zeppelin.common.JsonSerializable;
 import org.apache.zeppelin.dep.Dependency;
 import org.apache.zeppelin.interpreter.InterpreterOption;
 import org.apache.zeppelin.interpreter.InterpreterProperty;
@@ -29,12 +26,11 @@ import org.apache.zeppelin.interpreter.InterpreterProperty;
 /**
  * UpdateInterpreterSetting rest api request message.
  */
-public class UpdateInterpreterSettingRequest implements JsonSerializable {
-  private static final Gson gson = new Gson();
+public class UpdateInterpreterSettingRequest {
 
-  Map<String, InterpreterProperty> properties;
-  List<Dependency> dependencies;
-  InterpreterOption option;
+  private final Map<String, InterpreterProperty> properties;
+  private final List<Dependency> dependencies;
+  private final InterpreterOption option;
 
   public UpdateInterpreterSettingRequest(Map<String, InterpreterProperty> properties,
       List<Dependency> dependencies, InterpreterOption option) {
@@ -54,12 +50,4 @@ public class UpdateInterpreterSettingRequest implements JsonSerializable {
   public InterpreterOption getOption() {
     return option;
   }
-
-  public String toJson() {
-    return gson.toJson(this);
-  }
-
-  public static UpdateInterpreterSettingRequest fromJson(String json) {
-    return gson.fromJson(json, UpdateInterpreterSettingRequest.class);
-  }
 }
