@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.zeppelin.rest.message;
 
 /**
- * UpdateParagraphRequest
+ * UpdateParagraphRequest rest api request message.
  */
 public class UpdateParagraphRequest {
-  String title;
-  String text;
-
-  public UpdateParagraphRequest() {
+  private final String title;
+  private final String text;
 
+  public UpdateParagraphRequest(String title, String text) {
+    this.title = title;
+    this.text = text;
   }
 
   public String getTitle() {
@@ -35,6 +35,4 @@ public class UpdateParagraphRequest {
   public String getText() {
     return text;
   }
-
-
 }
