@@ -27,8 +27,8 @@ import java.util.Set;
  */
 public class ServiceContext {
 
-  private AuthenticationInfo autheInfo;
-  private Set<String> userAndRoles;
+  private final AuthenticationInfo autheInfo;
+  private final Set<String> userAndRoles;
 
   public ServiceContext(AuthenticationInfo authInfo, Set<String> userAndRoles) {
     this.autheInfo = authInfo;
