@@ -326,10 +326,8 @@ public abstract class AbstractTestRestApi {
         FileUtils.deleteQuietly(shiroIni);
       }
       LOG.info("Terminating Zeppelin Server...");
-      ZeppelinServer.jettyWebServer.stop();
       executor.shutdown();
-      PluginManager.reset();
-      ZeppelinConfiguration.reset();
+      executor.shutdownNow();
 
       long s = System.currentTimeMillis();
       boolean started = true;
@@ -357,7 +355,6 @@ public abstract class AbstractTestRestApi {
         FileUtils.deleteDirectory(confDir);
       }
       TestUtils.clearInstances();
-      ZeppelinServer.reset();
     }
   }
 
