@@ -29,6 +29,7 @@ import org.apache.zeppelin.utils.TestUtils;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.MethodOrderer;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.TestMethodOrder;
@@ -657,6 +658,7 @@ class ZeppelinRestApiTest extends AbstractTestRestApi {
     }
   }
 
+  @Disabled // TODO(ZEPPELIN-5994): Fix and enable this test
   @Test
   void testJobs() throws Exception {
     // create a note and a paragraph
@@ -719,6 +721,7 @@ class ZeppelinRestApiTest extends AbstractTestRestApi {
     }
   }
 
+  @Disabled // TODO(ZEPPELIN-5994): Fix and enable this test
   @Test
   void testCronDisable() throws Exception {
     String noteId = null;
