@@ -19,18 +19,16 @@ package org.apache.zeppelin.notebook;
 import org.apache.zeppelin.scheduler.Job;
 import org.apache.zeppelin.user.AuthenticationInfo;
 
-import java.io.IOException;
-
 /**
  * Notebook event
  */
 public interface NoteEventListener {
-  void onNoteRemove(Note note, AuthenticationInfo subject) throws IOException;
-  void onNoteCreate(Note note, AuthenticationInfo subject) throws IOException;
-  void onNoteUpdate(Note note, AuthenticationInfo subject) throws IOException;
+  void onNoteRemove(Note note, AuthenticationInfo subject);
+  void onNoteCreate(Note note, AuthenticationInfo subject);
+  void onNoteUpdate(Note note, AuthenticationInfo subject);
 
-  void onParagraphRemove(Paragraph p) throws IOException;
-  void onParagraphCreate(Paragraph p) throws IOException;
-  void onParagraphUpdate(Paragraph p) throws IOException;
-  void onParagraphStatusChange(Paragraph p, Job.Status status) throws IOException;
+  void onParagraphRemove(Paragraph p);
+  void onParagraphCreate(Paragraph p);
+  void onParagraphUpdate(Paragraph p);
+  void onParagraphStatusChange(Paragraph p, Job.Status status);
 }
