@@ -23,7 +23,7 @@ import org.apache.zeppelin.scheduler.JobListener;
 /**
  * Listener for Paragraph Job.
  */
-public interface ParagraphJobListener extends JobListener<Paragraph> {
+public interface ParagraphJobListener extends JobListener {
   //TODO(savalek) Temporary solution. Need to refactor cron to be able to notify frontend directly.
   void noteRunningStatusChange(String noteId, boolean newStatus);
 }
