@@ -17,7 +17,12 @@
 
 package org.apache.zeppelin.notebook.repo;
 
-import static com.google.common.truth.Truth.assertThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 
 import java.io.File;
@@ -25,7 +30,6 @@ import java.io.IOException;
 import java.util.List;
 import java.util.Map;
 
-import com.google.common.truth.Truth;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.zeppelin.conf.ZeppelinConfiguration;
@@ -39,10 +43,13 @@ import org.apache.zeppelin.user.AuthenticationInfo;
 import org.eclipse.jgit.api.Git;
 import org.eclipse.jgit.api.errors.GitAPIException;
 import org.eclipse.jgit.diff.DiffEntry;
+import org.eclipse.jgit.lib.ObjectId;
+import org.eclipse.jgit.lib.Repository;
 import org.eclipse.jgit.revwalk.RevCommit;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.eclipse.jgit.treewalk.TreeWalk;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -59,7 +66,7 @@ public class GitNotebookRepoTest {
   private ZeppelinConfiguration conf;
   private GitNotebookRepo notebookRepo;
 
-  @Before
+  @BeforeEach
   public void setUp() throws Exception {
     String zpath = System.getProperty("java.io.tmpdir") + "/ZeppelinTest_" + System.currentTimeMillis();
     zeppelinDir = new File(zpath);
@@ -81,7 +88,7 @@ public class GitNotebookRepoTest {
     conf = ZeppelinConfiguration.create();
   }
 
-  @After
+  @AfterEach
   public void tearDown() throws Exception {
     if (!FileUtils.deleteQuietly(zeppelinDir)) {
       LOG.error("Failed to delete {} ", zeppelinDir.getName());
@@ -92,52 +99,52 @@ public class GitNotebookRepoTest {
   public void initNonemptyNotebookDir() throws IOException, GitAPIException {
     //given - .git does not exit
     File dotGit = new File(String.join(File.separator, notebooksDir, ".git"));
-    assertThat(dotGit.exists()).isEqualTo(false);
+    assertFalse(dotGit.exists());
 
     //when
     notebookRepo = new GitNotebookRepo(conf);
 
     //then
     Git git = notebookRepo.getGit();
-    Truth.assertThat(git).isNotNull();
+    assertNotNull(git);
 
-    assertThat(dotGit.exists()).isEqualTo(true);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
+    assertTrue(dotGit.exists());
+    assertFalse(notebookRepo.list(null).isEmpty());
 
     List<DiffEntry> diff = git.diff().call();
     // no commit, diff isn't empty
-    Truth.assertThat(diff).isNotEmpty();
+    assertFalse(diff.isEmpty());
   }
 
   @Test
   public void showNotebookHistoryEmptyTest() throws GitAPIException, IOException {
     //given
     notebookRepo = new GitNotebookRepo(conf);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
+    assertFalse(notebookRepo.list(null).isEmpty());
 
     //when
     List<Revision> testNotebookHistory = notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null);
 
     //then
     //no initial commit, empty history
-    assertThat(testNotebookHistory).isEmpty();
+    assertTrue(testNotebookHistory.isEmpty());
   }
 
   @Test
   public void showNotebookHistoryMultipleNotesTest() throws IOException {
     //initial checks
     notebookRepo = new GitNotebookRepo(conf);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
-    assertThat(containsNote(notebookRepo.list(null), TEST_NOTE_ID)).isTrue();
-    assertThat(containsNote(notebookRepo.list(null), TEST_NOTE_ID2)).isTrue();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null)).isEmpty();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null)).isEmpty();
+    assertFalse(notebookRepo.list(null).isEmpty());
+    assertTrue(containsNote(notebookRepo.list(null), TEST_NOTE_ID));
+    assertTrue(containsNote(notebookRepo.list(null), TEST_NOTE_ID2));
+    assertTrue(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).isEmpty());
+    assertTrue(notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).isEmpty());
 
     //add commit to both notes
     notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit, note1", null);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(1);
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
     notebookRepo.checkpoint(TEST_NOTE_ID2, TEST_NOTE_PATH2, "first commit, note2", null);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size()).isEqualTo(1);
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size());
 
     //modify, save and checkpoint first note
     Note note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
@@ -148,12 +155,11 @@ public class GitNotebookRepoTest {
     p.setConfig(config);
     p.setText("%md note1 test text");
     notebookRepo.save(note, null);
-    assertThat(notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "second commit, note1", null)).isNotNull();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(2);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size()).isEqualTo(1);
-    assertThat(notebookRepo.checkpoint(TEST_NOTE_ID2, TEST_NOTE_PATH2, "first commit, note2", null))
-      .isEqualTo(Revision.EMPTY);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size()).isEqualTo(1);
+    assertNotNull(notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "second commit, note1", null));
+    assertEquals(2, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size());
+    assertEquals(Revision.EMPTY, notebookRepo.checkpoint(TEST_NOTE_ID2, TEST_NOTE_PATH2, "first commit, note2", null));
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size());
 
     //modify, save and checkpoint second note
     note = notebookRepo.get(TEST_NOTE_ID2, TEST_NOTE_PATH2, null);
@@ -164,22 +170,22 @@ public class GitNotebookRepoTest {
     p.setConfig(config);
     p.setText("%md note2 test text");
     notebookRepo.save(note, null);
-    assertThat(notebookRepo.checkpoint(TEST_NOTE_ID2, TEST_NOTE_PATH2, "second commit, note2", null)).isNotNull();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(2);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size()).isEqualTo(2);
+    assertNotNull(notebookRepo.checkpoint(TEST_NOTE_ID2, TEST_NOTE_PATH2, "second commit, note2", null));
+    assertEquals(2, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
+    assertEquals(2, notebookRepo.revisionHistory(TEST_NOTE_ID2, TEST_NOTE_PATH2, null).size());
   }
 
   @Test
   public void addCheckpointTest() throws IOException, GitAPIException {
     // initial checks
     notebookRepo = new GitNotebookRepo(conf);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
-    assertThat(containsNote(notebookRepo.list(null), TEST_NOTE_ID)).isTrue();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null)).isEmpty();
+    assertFalse(notebookRepo.list(null).isEmpty());
+    assertTrue(containsNote(notebookRepo.list(null), TEST_NOTE_ID));
+    assertTrue(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).isEmpty());
 
     notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit", null);
     List<Revision> notebookHistoryBefore = notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null)).isNotEmpty();
+    assertFalse(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).isEmpty());
     int initialCount = notebookHistoryBefore.size();
 
     // add changes to note
@@ -197,7 +203,7 @@ public class GitNotebookRepoTest {
 
     // see if commit is added
     List<Revision> notebookHistoryAfter = notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null);
-    assertThat(notebookHistoryAfter.size()).isEqualTo(initialCount + 1);
+    assertEquals(initialCount + 1, notebookHistoryAfter.size());
 
     int revCountBefore = 0;
     Iterable<RevCommit> revCommits = notebookRepo.getGit().log().call();
@@ -224,7 +230,7 @@ public class GitNotebookRepoTest {
     for (RevCommit revCommit : revCommits) {
       revCountAfter++;
     }
-    assertThat(revCountAfter).isEqualTo(revCountBefore);
+    assertEquals(revCountBefore, revCountAfter);
   }
 
   private boolean containsNote(Map<String, NoteInfo> notes, String noteId) {
@@ -240,13 +246,13 @@ public class GitNotebookRepoTest {
   public void getRevisionTest() throws IOException {
     // initial checks
     notebookRepo = new GitNotebookRepo(conf);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
-    assertThat(containsNote(notebookRepo.list(null), TEST_NOTE_ID)).isTrue();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null)).isEmpty();
+    assertFalse(notebookRepo.list(null).isEmpty());
+    assertTrue(containsNote(notebookRepo.list(null), TEST_NOTE_ID));
+    assertTrue(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).isEmpty());
 
     // add first checkpoint
     Revision revision_1 = notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit", null);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(1);
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
     int paragraphCount_1 = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null).getParagraphs().size();
 
     // add paragraph and save
@@ -261,18 +267,18 @@ public class GitNotebookRepoTest {
 
     // second checkpoint
     notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "second commit", null);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(2);
+    assertEquals(2, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
     int paragraphCount_2 = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null).getParagraphs().size();
-    assertThat(paragraphCount_2).isEqualTo(paragraphCount_1 + 1);
+    assertEquals(paragraphCount_1 + 1, paragraphCount_2);
 
     // get note from revision 1
     Note noteRevision_1 = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, revision_1.id, null);
-    assertThat(noteRevision_1.getParagraphs().size()).isEqualTo(paragraphCount_1);
+    assertEquals(paragraphCount_1, noteRevision_1.getParagraphs().size());
 
     // get current note
     note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
     note.setInterpreterFactory(mock(InterpreterFactory.class));
-    assertThat(note.getParagraphs().size()).isEqualTo(paragraphCount_2);
+    assertEquals(paragraphCount_2, note.getParagraphs().size());
 
     // add one more paragraph and save
     Paragraph p2 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -283,34 +289,34 @@ public class GitNotebookRepoTest {
     note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
     note.setInterpreterFactory(mock(InterpreterFactory.class));
     int paragraphCount_3 = note.getParagraphs().size();
-    assertThat(paragraphCount_3).isEqualTo(paragraphCount_2 + 1);
+    assertEquals(paragraphCount_2 + 1, paragraphCount_3);
 
     // get revision 1 again
     noteRevision_1 = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, revision_1.id, null);
-    assertThat(noteRevision_1.getParagraphs().size()).isEqualTo(paragraphCount_1);
+    assertEquals(paragraphCount_1, noteRevision_1.getParagraphs().size());
 
     // check that note is unchanged
     note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
-    assertThat(note.getParagraphs().size()).isEqualTo(paragraphCount_3);
+    assertEquals(paragraphCount_3, note.getParagraphs().size());
   }
 
   @Test
   public void getRevisionFailTest() throws IOException {
     // initial checks
     notebookRepo = new GitNotebookRepo(conf);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
-    assertThat(containsNote(notebookRepo.list(null), TEST_NOTE_ID)).isTrue();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null)).isEmpty();
+    assertFalse(notebookRepo.list(null).isEmpty());
+    assertTrue(containsNote(notebookRepo.list(null), TEST_NOTE_ID));
+    assertTrue(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).isEmpty());
 
     // add first checkpoint
     Revision revision_1 = notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit", null);
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(1);
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
     int paragraphCount_1 = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null).getParagraphs().size();
 
     // get current note
     Note note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
     note.setInterpreterFactory(mock(InterpreterFactory.class));
-    assertThat(note.getParagraphs().size()).isEqualTo(paragraphCount_1);
+    assertEquals(paragraphCount_1, note.getParagraphs().size());
 
     // add one more paragraph and save
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -323,26 +329,26 @@ public class GitNotebookRepoTest {
 
     // get note from revision 1
     Note noteRevision_1 = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, revision_1.id, null);
-    assertThat(noteRevision_1.getParagraphs().size()).isEqualTo(paragraphCount_1);
+    assertEquals(paragraphCount_1, noteRevision_1.getParagraphs().size());
 
     // get current note
     note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
     note.setInterpreterFactory(mock(InterpreterFactory.class));
-    assertThat(note.getParagraphs().size()).isEqualTo(paragraphCount_2);
+    assertEquals(paragraphCount_2, note.getParagraphs().size());
 
     // test for absent revision
     Revision absentRevision = new Revision("absentId", StringUtils.EMPTY, 0);
     note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, absentRevision.id, null);
-    assertThat(note).isNull();
+    assertNull(note);
   }
 
   @Test
   public void setRevisionTest() throws IOException {
     //create repo and check that note doesn't contain revisions
     notebookRepo = new GitNotebookRepo(conf);
-    assertThat(notebookRepo.list(null)).isNotEmpty();
-    assertThat(containsNote(notebookRepo.list(null), TEST_NOTE_ID)).isTrue();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null)).isEmpty();
+    assertFalse(notebookRepo.list(null).isEmpty());
+    assertTrue(containsNote(notebookRepo.list(null), TEST_NOTE_ID));
+    assertTrue(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).isEmpty());
 
     // get current note
     Note note = notebookRepo.get(TEST_NOTE_ID, TEST_NOTE_PATH, null);
@@ -353,8 +359,8 @@ public class GitNotebookRepoTest {
     // checkpoint revision1
     Revision revision1 = notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "set revision: first commit", null);
     //TODO(khalid): change to EMPTY after rebase
-    assertThat(revision1).isNotNull();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(1);
+    assertNotNull(revision1);
+    assertEquals(1, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
 
     // add one more paragraph and save
     Paragraph p1 = note.addNewParagraph(AuthenticationInfo.ANONYMOUS);
@@ -364,37 +370,129 @@ public class GitNotebookRepoTest {
     p1.setText("set revision sample text");
     notebookRepo.save(note, null);
     int paragraphCount_2 = note.getParagraphs().size();
-    assertThat(paragraphCount_2).isEqualTo(paragraphCount_1 + 1);
+    assertEquals(paragraphCount_1 + 1, paragraphCount_2);
     LOG.info("paragraph count after modification: {}", paragraphCount_2);
 
     // checkpoint revision2
     Revision revision2 = notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "set revision: second commit", null);
     //TODO(khalid): change to EMPTY after rebase
-    assertThat(revision2).isNotNull();
-    assertThat(notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size()).isEqualTo(2);
+    assertNotNull(revision2);
+    assertEquals(2, notebookRepo.revisionHistory(TEST_NOTE_ID, TEST_NOTE_PATH, null).size());
 
     // set note to revision1
     Note returnedNote = notebookRepo.setNoteRevision(note.getId(), note.getPath(), revision1.id, null);
-    assertThat(returnedNote).isNotNull();
-    assertThat(returnedNote.getParagraphs().size()).isEqualTo(paragraphCount_1);
+    assertNotNull(returnedNote);
+    assertEquals(paragraphCount_1, returnedNote.getParagraphs().size());
 
     // check note from repo
     Note updatedNote = notebookRepo.get(note.getId(), note.getPath(), null);
-    assertThat(updatedNote).isNotNull();
-    assertThat(updatedNote.getParagraphs().size()).isEqualTo(paragraphCount_1);
+    assertNotNull(updatedNote);
+    assertEquals(paragraphCount_1, updatedNote.getParagraphs().size());
 
     // set back to revision2
     returnedNote = notebookRepo.setNoteRevision(note.getId(), note.getPath(), revision2.id, null);
-    assertThat(returnedNote).isNotNull();
-    assertThat(returnedNote.getParagraphs().size()).isEqualTo(paragraphCount_2);
+    assertNotNull(returnedNote);
+    assertEquals(paragraphCount_2, returnedNote.getParagraphs().size());
 
     // check note from repo
     updatedNote = notebookRepo.get(note.getId(), note.getPath(), null);
-    assertThat(updatedNote).isNotNull();
-    assertThat(updatedNote.getParagraphs().size()).isEqualTo(paragraphCount_2);
+    assertNotNull(updatedNote);
+    assertEquals(paragraphCount_2, updatedNote.getParagraphs().size());
 
     // try failure case - set to invalid revision
     returnedNote = notebookRepo.setNoteRevision(note.getId(), note.getPath(), "nonexistent_id", null);
-    assertThat(returnedNote).isNull();
+    assertNull(returnedNote);
+  }
+
+  @Test
+  public void moveNoteTest() throws IOException, GitAPIException {
+    //given
+    notebookRepo = new GitNotebookRepo(conf);
+    notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit, note1", null);
+
+    //when
+    final String NOTE_FILENAME = TEST_NOTE_PATH.substring(TEST_NOTE_PATH.lastIndexOf("/") + 1);
+    final String MOVE_DIR = "/move";
+    final String TEST_MOVE_PATH = MOVE_DIR + "/" + NOTE_FILENAME;
+    new File(notebooksDir + MOVE_DIR).mkdirs();
+    notebookRepo.move(TEST_NOTE_ID, TEST_NOTE_PATH, TEST_MOVE_PATH, null);
+
+    //then
+    assertFileIsMoved();
+  }
+
+  @Test
+  public void moveFolderTest() throws IOException, GitAPIException {
+    //given
+    notebookRepo = new GitNotebookRepo(conf);
+    notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit, note1", null);
+    notebookRepo.checkpoint(TEST_NOTE_ID2, TEST_NOTE_PATH2, "second commit, note2", null);
+
+    //when
+    final String NOTE_DIR = TEST_NOTE_PATH.substring(0, TEST_NOTE_PATH.lastIndexOf("/"));
+    final String MOVE_DIR = "/move";
+    new File(notebooksDir + MOVE_DIR).mkdirs();
+    notebookRepo.move(NOTE_DIR, MOVE_DIR, null);
+
+    //then
+    assertFileIsMoved();
+  }
+
+  @Test
+  public void removeNoteTest() throws IOException, GitAPIException {
+    //given
+    notebookRepo = new GitNotebookRepo(conf);
+    notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit, note1", null);
+
+    //when
+    notebookRepo.remove(TEST_NOTE_ID, TEST_NOTE_PATH, null);
+
+    //then
+    assertFileIsDeleted();
+  }
+
+  @Test
+  public void removeFolderTest() throws IOException, GitAPIException {
+    //given
+    notebookRepo = new GitNotebookRepo(conf);
+    notebookRepo.checkpoint(TEST_NOTE_ID, TEST_NOTE_PATH, "first commit, note1", null);
+
+    //when
+    final String NOTE_DIR = TEST_NOTE_PATH.substring(0, TEST_NOTE_PATH.lastIndexOf("/"));
+    notebookRepo.remove(NOTE_DIR, null);
+
+    //then
+    assertFileIsDeleted();
+  }
+
+  private void assertFileIsMoved() throws IOException, GitAPIException {
+    Git git = notebookRepo.getGit();
+    RevCommit latestCommit = git.log().call().iterator().next();
+    ObjectId treeId = latestCommit.getTree().getId();
+    Repository repository = git.getRepository();
+
+    try (TreeWalk treeWalk = new TreeWalk(repository)) {
+      treeWalk.reset(treeId);
+      treeWalk.next();
+      RevCommit previousCommit = latestCommit.getParent(0);
+      try (TreeWalk previousTreeWalk = new TreeWalk(repository)) {
+        previousTreeWalk.reset(previousCommit.getTree());
+        previousTreeWalk.next();
+        assertNotEquals(treeWalk.getPathString(), previousTreeWalk.getPathString());
+        assertEquals(treeWalk.getObjectId(0), previousTreeWalk.getObjectId(0));
+      }
+    }
+  }
+
+  private void assertFileIsDeleted() throws IOException, GitAPIException {
+    Git git = notebookRepo.getGit();
+    RevCommit latestCommit = git.log().call().iterator().next();
+    ObjectId treeId = latestCommit.getTree().getId();
+    Repository repository = git.getRepository();
+
+    try (TreeWalk treeWalk = new TreeWalk(repository)) {
+      treeWalk.reset(treeId);
+      assertFalse(treeWalk.next());
+    }
   }
 }
